@@ -18,6 +18,9 @@
  */
 
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <iostream>
 #include <algorithm>
@@ -28,6 +31,7 @@
 #include <gtk/gtk.h>
 
 #include <glibmm/i18n.h>
+#include <glibmm/spawn.h>
 #include <gtkmm/icontheme.h>
 #include <gtkmm/image.h>
 #include <gtkmm/stock.h>
@@ -84,18 +88,13 @@ namespace gnote {
       }
     }
 
+
     void popup_menu(Gtk::Menu &menu, const GdkEventButton * ev)
-    {
-      popup_menu(menu, ev, boost::bind(&get_menu_position, &menu, _1, _2, _3));
-    }
-
-
-    void popup_menu(Gtk::Menu &menu, const GdkEventButton * ev, 
-                    Gtk::Menu::SlotPositionCalc calc)
     {
       menu.signal_deactivate().connect(sigc::bind(&deactivate_menu, &menu));
-      menu.popup(calc, (ev ? ev->button : 0), 
-                  (ev ? ev->time : gtk_get_current_event_time()));
+      menu.popup(boost::bind(&get_menu_position, &menu, _1, _2, _3), 
+                 (ev ? ev->button : 0), 
+                 (ev ? ev->time : gtk_get_current_event_time()));
       if(menu.get_attach_widget()) {
         menu.get_attach_widget()->set_state(Gtk::STATE_SELECTED);
       }
@@ -105,7 +104,7 @@ namespace gnote {
     Glib::RefPtr<Gdk::Pixbuf> get_icon(const std::string & name, int size)
     {
       try {
-        return Gtk::IconTheme::get_default()->load_icon(name, size);
+        return Gtk::IconTheme::get_default()->load_icon(name, size, (Gtk::IconLookupFlags) 0);
       }
       catch(const Glib::Exception & e)
       {
@@ -119,10 +118,11 @@ namespace gnote {
     {
       std::string uri = "ghelp:" + filename;
       if(!link_id.empty()) {
-        uri += link_id;
+        uri += "#" + link_id;
       }
       GError *error = NULL;
 
+#ifdef HAVE_GTK_SHOW_URI
       if(!gtk_show_uri (screen, uri.c_str(), gtk_get_current_event_time (), &error)) {
         
         std::string message = _("The \"Gnote Manual\" could "
@@ -140,8 +140,30 @@ namespace gnote {
           g_error_free(error);
         }
       }
+#else
+      Glib::spawn_command_line_async ("xdg-open " + uri);
+#endif
     }
 
+
+    void open_url(const std::string & url)
+      throw (Glib::Error)
+    {
+      if(!url.empty()) {
+        GError *err = NULL;
+        DBG_OUT("Opening url '%s'...", url.c_str());
+#ifdef HAVE_GTK_SHOW_URI
+        gtk_show_uri (NULL, url.c_str(), GDK_CURRENT_TIME, &err);
+#else
+        Glib::spawn_command_line_async ("xdg-open " + url);
+#endif
+        if(err) {
+          throw Glib::Error(err, true);
+        }
+      }
+    }
+
+
     void show_opening_location_error(Gtk::Window * parent, 
                                      const std::string & url, 
                                      const std::string & error)
@@ -668,30 +690,46 @@ namespace gnote {
     }
 
     ToolMenuButton::ToolMenuButton(Gtk::Toolbar& toolbar, const Gtk::BuiltinStockID& stock_image, 
-                                   const Glib::ustring & label, Gtk::Menu & menu)
+                                   const Glib::ustring & label, 
+                                   Gtk::Menu * menu)
       : Gtk::ToggleToolButton(label)
       ,  m_menu(menu)
     {
-      set_icon_widget(*manage(new Gtk::Image(stock_image, toolbar.get_icon_size())));
-      property_can_focus().set_value(true);
-      gtk_menu_attach_to_widget(menu.gobj(), static_cast<Gtk::Widget*>(this)->gobj(),
+      _common_init(*manage(new Gtk::Image(stock_image, toolbar.get_icon_size())));
+    }
+
+    ToolMenuButton::ToolMenuButton(Gtk::Image& image, 
+                                   const Glib::ustring & label, 
+                                   Gtk::Menu * menu)
+      : Gtk::ToggleToolButton(label)
+      ,  m_menu(menu)
+    {
+      _common_init(image);
+    }
+
+
+    void ToolMenuButton::_common_init(Gtk::Image& image)
+    {
+      set_icon_widget(image);
+      property_can_focus() = true;
+      gtk_menu_attach_to_widget(m_menu->gobj(), static_cast<Gtk::Widget*>(this)->gobj(),
                                 NULL);
 //      menu.attach_to_widget(*this);
-      menu.signal_deactivate().connect(sigc::mem_fun(*this, &ToolMenuButton::release_button));
+      m_menu->signal_deactivate().connect(sigc::mem_fun(*this, &ToolMenuButton::release_button));
       show_all();
     }
 
 
     bool ToolMenuButton::on_button_press_event(GdkEventButton *ev)
     {
-      popup_menu(m_menu, ev);
+      popup_menu(*m_menu, ev);
       return true;
     }
 
     void ToolMenuButton::on_clicked()
     {
-      m_menu.select_first(true);
-      popup_menu(m_menu, NULL);
+      m_menu->select_first(true);
+      popup_menu(*m_menu, NULL);
     }
 
     bool ToolMenuButton::on_mnemonic_activate(bool group_cycling)
